package com.sun.tools.javac.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "21.0.2+13-LTS" },
            { "jdk", "21.0.2" },
            { "release", "21.0.2" },
        };
    }
}
